@@ -216,22 +216,44 @@ class MiniRpaManager(MiniRpaFunction):
                      tab_index,
                      has_range,
                      start_range,
-                     end_range
-
-                     ) = (sap_operation_dict['query_button_index'],
-                          sap_operation_dict['query_value_input_method'],
-                          sap_operation_dict['remote_folder_path'],
-                          sap_operation_dict['query_value_columns'],
-                          sap_operation_dict['file_name'],
-                          sap_operation_dict['sheet_name'],
-                          sap_operation_dict['tab_index'],
-                          sap_operation_dict.get('has_range', False),
-                          sap_operation_dict.get('start_range', None),
-                          sap_operation_dict.get('end_range', None),
-                          )
+                     end_range) = (sap_operation_dict['query_button_index'],
+                                   sap_operation_dict['query_value_input_method'],
+                                   sap_operation_dict['remote_folder_path'],
+                                   sap_operation_dict['query_value_columns'],
+                                   sap_operation_dict['file_name'],
+                                   sap_operation_dict['sheet_name'],
+                                   sap_operation_dict['tab_index'],
+                                   sap_operation_dict.get('has_range', False),
+                                   sap_operation_dict.get('start_range', None),
+                                   sap_operation_dict.get('end_range', None),
+                                   )
                     query_value_columns = query_value_columns.split(',') if query_value_columns else None
                     sap_automation.input_query_values_from_existed_data(int(query_button_index), query_value_input_method, remote_folder_path, query_value_columns, file_name,
                                                                         sheet_name, int(tab_index), has_range, start_range, end_range)
+                elif function_name == 'input_query_values_from_existed_data_by_field_label':
+                    (field_label,
+                     query_value_input_method,
+                     remote_folder_path,
+                     query_value_columns,
+                     file_name,
+                     sheet_name,
+                     tab_index,
+                     has_range,
+                     start_range,
+                     end_range) = (sap_operation_dict['field_label'],
+                                   sap_operation_dict['query_value_input_method'],
+                                   sap_operation_dict['remote_folder_path'],
+                                   sap_operation_dict['query_value_columns'],
+                                   sap_operation_dict['file_name'],
+                                   sap_operation_dict['sheet_name'],
+                                   sap_operation_dict['tab_index'],
+                                   sap_operation_dict.get('has_range', False),
+                                   sap_operation_dict.get('start_range', None),
+                                   sap_operation_dict.get('end_range', None),
+                                   )
+                    query_value_columns = query_value_columns.split(',') if query_value_columns else None
+                    sap_automation.input_query_values_from_existed_data_by_field_label(field_label, query_value_input_method, remote_folder_path, query_value_columns, file_name,
+                                                                                       sheet_name, int(tab_index), has_range, start_range, end_range)
                 elif function_name == 'find_variant_by_name':
                     sap_automation.find_variant_by_name(sap_operation_dict['variant_name'])
                 elif function_name == 'find_abap_variant_by_name':
