@@ -8,7 +8,8 @@ from BoschRpaMagicBox.common_functions import *
 SE16_TABLE_NAME_INPUT_CSS_SELECTOR = "input[title='Table Name']"
 POPUP_WINDOW_OK_BUTTON_CSS_SELECTOR = ".urPWInnerBorder div[title='Continue (Enter)']"
 REPORTING_PERIOD_CSS_SELECTOR = "div[title^='Reporting Period:']"
-REPORTING_PERIOD_DROPDOWN_CSS_SELECTOR = "input[aria-roledescription='Dropdown List Box'"
+# REPORTING_PERIOD_DROPDOWN_CSS_SELECTOR = "input[aria-roledescription='Dropdown List Box']"
+REPORTING_PERIOD_DROPDOWN_CSS_SELECTOR = "input[value='Key Date']"
 REPORTING_PERIOD_DROPDOWN_LIST_CSS_SELECTOR = "#DD_DATESAPLHR_QUERY_APPL_AREA-scrl div.lsListbox__values"
 QUERY_PARAMETER_TR_CSS_SELECTOR = "table[id$='mrss-cont-none-content'] tr[id*='mrss-cont-none-Row'][id^='C']"
 OUTPUT_BUTTON_CSS_SELECTOR = "div[title='Start output (F8)']"
@@ -693,6 +694,56 @@ class MiniRpaSapAutomation:
             self.skip_download_process = True
             self.back_to_home_page()
 
+    def input_query_values_from_existed_data_by_field_label(self, field_label, query_value_input_method='local_file', remote_folder_path='', query_value_columns=None,
+                                                            file_name='', sheet_name='Sheet1', tab_index=1, has_range=False, start_range=None, end_range=None):
+        """ This function is used to input query values.
+
+        Args:
+            field_label(str): This is the label of field name
+            query_value_input_method(str): This is the method to input query values. remote_file or local_file
+            remote_folder_path(str): This is the path of remote folder
+            query_value_columns(list): This is the list of query columns
+            file_name(str): This is the path of file
+            sheet_name(str): This is the name of sheet
+            tab_index(int): This is the index of tab
+            has_range(bool): This indicates whether to has range
+            start_range(int): This is the start range of data
+            end_range(int): This is the end range of data
+        """
+        if query_value_columns is None:
+            query_value_columns = []
+
+        is_file_exist, file_data = self.load_downloaded_excel_file(query_value_input_method, file_name, sheet_name, remote_folder_path)
+        if is_file_exist:
+            if has_range and not file_data.empty:
+                start_range = abs(int(start_range)) - 1 if start_range else 0
+                end_range = abs(int(end_range)) if end_range else file_data.shape[0]
+
+                start_range = 0 if start_range < 0 else start_range
+                end_range = file_data.shape[0] if end_range > file_data.shape[0] else end_range
+
+                if start_range > end_range:
+                    start_range, end_range = end_range, start_range
+
+                file_data = file_data.iloc[start_range:end_range, :]
+                if file_data.empty:
+                    print(f'No data found in the range: {start_range} - {end_range}')
+                    self.skip_download_process = True
+                    self.back_to_home_page()
+
+            if len(query_value_columns) == 2:
+                file_data['paste_column'] = file_data[query_value_columns[0]] + '\t' + file_data[query_value_columns[1]]
+                query_value_list = file_data['paste_column'].tolist()
+            elif len(query_value_columns) == 1:
+                query_value_list = file_data[query_value_columns[0]].tolist()
+            else:
+                raise ValueError('The query_value_columns should be correct values!')
+            self.web_rpa.input_multiple_selection_with_field_label(query_value_list, field_label, tab_index, clear_section_data=True)
+            sleep(2)
+        else:
+            self.skip_download_process = True
+            self.back_to_home_page()
+
     def load_downloaded_excel_file(self, query_value_input_method, file_name, sheet_name='Sheet1', remote_folder_path=''):
         """ This function is used to load downloaded Excel file.
 
